@@ -1,5 +1,5 @@
 /*
-   Copyright 2005,2006,2007 Red Hat, Inc.
+   Copyright 2005,2006,2007,2015 Red Hat, Inc.
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -1397,6 +1397,7 @@ free_acl(struct oddjob_acl *acl)
 		oddjob_free(tofree->selinux_user);
 		oddjob_free(tofree->selinux_role);
 		oddjob_free(tofree->selinux_type);
+		oddjob_free(tofree->selinux_range);
 #endif
 		oddjob_free(tofree->user);
 		oddjob_free(tofree);
@@ -2526,7 +2527,7 @@ method_add_internal(struct oddjob_config *config,
 	method->argument_passing_method = oddjob_argument_passing_invalid;
 }
 
-static void 
+static void
 config_add_internal_methods(struct oddjob_config *config)
 {
 	method_add_internal(config, ODDJOB_SERVICE_NAME, ODDJOB_OBJECT_PATH,
@@ -2730,14 +2731,14 @@ config_register(struct oddjob_dbus_context *ctx, struct oddjob_config *config,
 					/* If the handler used NULL, give it
 					 * the method structure address, which
 					 * wasn't fixed until now. */
-					reg = oddjob_dbus_listener_add_method(ctx,
-									      service->name,
-									      object->name,
-									      interface->name,
-									      method->name,
-									      method->n_arguments,
-									      method->handler,
-									      method);
+					reg = oddjob_dbus_listeners_add_method(ctx,
+									       service->name,
+									       object->name,
+									       interface->name,
+									       method->name,
+									       method->n_arguments,
+									       method->handler,
+									       method);
 					if (!reg) {
 						fprintf(stderr, "Error initializing service \"%s\"!\n",
 							service->name);
@@ -2788,11 +2789,11 @@ config_unregister_removed(struct oddjob_dbus_context *ctx,
 								interface->name,
 								method->name);
 						}
-						oddjob_dbus_listener_remove_method(ctx,
-										   service->name,
-										   object->name,
-										   interface->name,
-										   method->name);
+						oddjob_dbus_listeners_remove_method(ctx,
+										    service->name,
+										    object->name,
+										    interface->name,
+										    method->name);
 					}
 				}
 			}
@@ -2984,13 +2985,13 @@ main(int argc, char **argv)
 	globals.config = config;
 
 	/* Open a connection to the message bus. */
-	ctx = oddjob_dbus_listener_new(options.bus);
+	ctx = oddjob_dbus_listeners_new(options.bus);
 	if (ctx == NULL) {
 		fprintf(stderr, "Error connecting to D-Bus!\n");
 		return 2;
 	}
-	oddjob_dbus_listener_set_reconnect_timeout(ctx,
-						   options.reconnect_timeout);
+	oddjob_dbus_listeners_set_reconnect_timeout(ctx,
+						    options.reconnect_timeout);
 
 	/* Add introspection methods to every object. */
 	config_add_introspection_methods(config);
@@ -3066,21 +3067,19 @@ main(int argc, char **argv)
 	}
 
 	/* Now sit! */
-	oddjob_dbus_main_init(ctx);
 	globals.quit = 0;
 	while (globals.quit == 0) {
 		if (globals.reload) {
 			oddjobd_reload_configuration(ctx, NULL);
 			globals.reload = 0;
 		}
-		oddjob_dbus_listener_reconnect_if_needed(ctx);
+		oddjob_dbus_listeners_reconnect_if_needed(ctx);
 		oddjob_dbus_main_iterate(ctx);
 	}
-	oddjob_dbus_main_done(ctx);
 
 	/* Clean up and exit. */
 	unload_config(globals.config);
-	oddjob_dbus_listener_free(ctx);
+	oddjob_dbus_listeners_free(ctx);
 	if (options.pidfile != NULL) {
 		unlink(options.pidfile);
 	}
